@@ -1,38 +1,19 @@
-# flake8: noqa
-
 # PEP0440 compatible formatted version, see:
 # https://www.python.org/dev/peps/pep-0440/
 #
 # Generic release markers:
 #   X.Y.0   # For first release after an increment in Y
 #   X.Y.Z   # For bugfix releases
-__version__ = '0.1.4'
+__version__ = '0.2.0'
 
-import inspect as inspect
 import json as json
-import sys as sys
-from typing import Set as Set, Type as Type, Tuple as Tuple
+from typing import Optional, Set as Set, Tuple as Tuple, Type as Type, Union
 
 from .jsonable import Jsonable
 
+JSONDataType = Optional[Union[dict, list, tuple, str, int, float, bool]]
 
-def __get_jsonables() -> Set[Type[Jsonable]]:
-    result = set()
-
-    for module in sys.modules:
-        for _, member in inspect.getmembers(module, lambda m: inspect.isclass(m) and issubclass(m, Jsonable)):
-            result.add(member)
-
-    # g = globals().copy()
-    #
-    # for _, obj in g.items():
-    #     if inspect.isclass(obj) and issubclass(obj, Jsonable) and obj is not Jsonable:
-    #         result.add(obj)
-
-    return result
-
-
-_jsonables: Set[Type[Jsonable]] = __get_jsonables()
+_jsonables: Set[Type[Jsonable]] = set()
 
 
 class JsonableNotRegisteredError(ValueError):
@@ -55,6 +36,26 @@ def __get_type(s: str) -> Type[Jsonable]:
     raise JsonableNotRegisteredError(s)
 
 
+def jsonabled(cls: Type[Jsonable]):
+    register_jsonables({cls})
+
+    return cls
+
+
+def register_jsonables(josanable_types: Set[Type[Jsonable]]) -> None:
+    """
+    Registers Jsonable types for being loaded from JSON encoded strings.
+    It is necessary to register your Jsonable types before loading them.
+
+    :param josanable_types: Jsonable types to register.
+    :return: None.
+    """
+
+    assert type(josanable_types), Set[Type[Jsonable]]
+
+    _jsonables.update(josanable_types)
+
+
 def loads(s: str) -> Jsonable:
     """
     Decodes a JSON encoded string and return a Jsonable type object.
@@ -70,7 +71,7 @@ def loads(s: str) -> Jsonable:
         encoded object, but the encoded Jsonable object type has not been registered.
     """
 
-    t: Tuple[str, dict] = tuple(json.loads(s))
+    t: Tuple[str, JSONDataType] = tuple(json.loads(s))
 
     if len(t) < 2:
         raise JsonableDecodeError("Input string is not a valid Jsonable encoded object")
